import { DependencyContainer } from "tsyringe";

import { ConfigServer } from "@spt-aki/servers/ConfigServer";
import { ConfigTypes } from "@spt-aki/models/enums/ConfigTypes";
import { DatabaseServer } from "@spt-aki/servers/DatabaseServer";
import { IPostDBLoadMod } from "@spt-aki/models/external/IPostDBLoadMod";

class KHCM implements IPostDBLoadMod {
    private modConfig = require("../config/config.json");
    private questKeys = require("../config/keys.json");

    postDBLoad(container: DependencyContainer): void {
        const logger = container.resolve<ILogger>("WinstonLogger");
        const databaseServer = container.resolve<DatabaseServer>("DatabaseServer");
        const configServer = container.resolve<ConfigServer>("ConfigServer");

        const tables = databaseServer.getTables();
        const quests = tables.templates.quests;

		const locales = tables["locales"]["global"][this.modConfig.language];

		for (let QId in quests) {
			let desc = quests[QId].description;
			
			if (this.questKeys[QId]!=null) {
				let keyinfo = "\nKeys needed:\n"
				let keys = this.questKeys[QId].split(",")
				let altkey = "";
				for (let ki=0; ki<keys.length; ki++) {
					if (keys[ki].slice(-1)=="*") {
						keys[ki] = keys[ki].slice(0,keys[ki].length-1)
						altkey = (ki==0) ? " or" : "";
					}
					if (keys[ki].slice(-1)=="~") {
						keys[ki] = keys[ki].slice(0,keys[ki].length-1)
						altkey = " (perhaps)";
					}
					keyinfo += "•  " + (locales[keys[ki] + " Name"]) + altkey + "\n"
				}
				
				//logger.info(keyinfo);
				locales[desc] += keyinfo;
				
			}
		}
    }
}

    
module.exports = { mod: new KHCM() }